aboutsummaryrefslogtreecommitdiffstats
path: root/cfile.h
diff options
context:
space:
mode:
Diffstat (limited to 'cfile.h')
-rw-r--r--cfile.h112
1 files changed, 56 insertions, 56 deletions
diff --git a/cfile.h b/cfile.h
index cbe54b1562..3c9296ba43 100644
--- a/cfile.h
+++ b/cfile.h
@@ -63,67 +63,67 @@ struct packet_provider_data {
};
typedef struct _capture_file {
- epan_t *epan;
- file_state state; /* Current state of capture file */
- gchar *filename; /* Name of capture file */
- gchar *source; /* Temp file source, e.g. "Pipe from elsewhere" */
- gboolean is_tempfile; /* Is capture file a temporary file? */
- gboolean unsaved_changes; /* Does the capture file have changes that have not been saved? */
- gboolean stop_flag; /* Stop current processing (loading, searching, etc.) */
-
- gint64 f_datalen; /* Size of capture file data (uncompressed) */
- guint16 cd_t; /* File type of capture file */
- unsigned int open_type; /* open_routine index+1 used, if selected, or WTAP_TYPE_AUTO */
- gboolean iscompressed; /* TRUE if the file is compressed */
- int lnk_t; /* File link-layer type; could be WTAP_ENCAP_PER_PACKET */
- GArray *linktypes; /* Array of packet link-layer types */
- guint32 count; /* Total number of frames */
- guint64 packet_comment_count; /* Number of comments in frames (could be >1 per frame... */
- guint32 displayed_count; /* Number of displayed frames */
- guint32 marked_count; /* Number of marked frames */
- guint32 ignored_count; /* Number of ignored frames */
- guint32 ref_time_count; /* Number of time referenced frames */
- gboolean drops_known; /* TRUE if we know how many packets were dropped */
- guint32 drops; /* Dropped packets */
- nstime_t elapsed_time; /* Elapsed time */
- int snap; /* Maximum captured packet length; 0 if unknown */
- dfilter_t *rfcode; /* Compiled read filter program */
- dfilter_t *dfcode; /* Compiled display filter program */
- gchar *dfilter; /* Display filter string */
- gboolean redissecting; /* TRUE if currently redissecting (cf_redissect_packets) */
- gboolean read_lock; /* TRUE if currently processing a file (cf_read) */
- rescan_type redissection_queued; /* Queued redissection type. */
+ epan_t *epan;
+ file_state state; /* Current state of capture file */
+ gchar *filename; /* Name of capture file */
+ gchar *source; /* Temp file source, e.g. "Pipe from elsewhere" */
+ gboolean is_tempfile; /* Is capture file a temporary file? */
+ gboolean unsaved_changes; /* Does the capture file have changes that have not been saved? */
+ gboolean stop_flag; /* Stop current processing (loading, searching, etc.) */
+
+ gint64 f_datalen; /* Size of capture file data (uncompressed) */
+ guint16 cd_t; /* File type of capture file */
+ unsigned int open_type; /* open_routine index+1 used, if selected, or WTAP_TYPE_AUTO */
+ wtap_compression_type compression_type; /* Compression type of the file, or uncompressed */
+ int lnk_t; /* File link-layer type; could be WTAP_ENCAP_PER_PACKET */
+ GArray *linktypes; /* Array of packet link-layer types */
+ guint32 count; /* Total number of frames */
+ guint64 packet_comment_count; /* Number of comments in frames (could be >1 per frame... */
+ guint32 displayed_count; /* Number of displayed frames */
+ guint32 marked_count; /* Number of marked frames */
+ guint32 ignored_count; /* Number of ignored frames */
+ guint32 ref_time_count; /* Number of time referenced frames */
+ gboolean drops_known; /* TRUE if we know how many packets were dropped */
+ guint32 drops; /* Dropped packets */
+ nstime_t elapsed_time; /* Elapsed time */
+ int snap; /* Maximum captured packet length; 0 if unknown */
+ dfilter_t *rfcode; /* Compiled read filter program */
+ dfilter_t *dfcode; /* Compiled display filter program */
+ gchar *dfilter; /* Display filter string */
+ gboolean redissecting; /* TRUE if currently redissecting (cf_redissect_packets) */
+ gboolean read_lock; /* TRUE if currently processing a file (cf_read) */
+ rescan_type redissection_queued; /* Queued redissection type. */
/* search */
- gchar *sfilter; /* Filter, hex value, or string being searched */
- gboolean hex; /* TRUE if "Hex value" search was last selected */
- gboolean string; /* TRUE if "String" search was last selected */
- gboolean summary_data; /* TRUE if "String" search in "Packet list" (Info column) was last selected */
- gboolean decode_data; /* TRUE if "String" search in "Packet details" was last selected */
- gboolean packet_data; /* TRUE if "String" search in "Packet data" was last selected */
- guint32 search_pos; /* Byte position of last byte found in a hex search */
- guint32 search_len; /* Length of bytes matching the search */
- gboolean case_type; /* TRUE if case-insensitive text search */
- GRegex *regex; /* Set if regular expression search */
- search_charset_t scs_type; /* Character set for text search */
- search_direction dir; /* Direction in which to do searches */
- gboolean search_in_progress; /* TRUE if user just clicked OK in the Find dialog or hit <control>N/B */
+ gchar *sfilter; /* Filter, hex value, or string being searched */
+ gboolean hex; /* TRUE if "Hex value" search was last selected */
+ gboolean string; /* TRUE if "String" search was last selected */
+ gboolean summary_data; /* TRUE if "String" search in "Packet list" (Info column) was last selected */
+ gboolean decode_data; /* TRUE if "String" search in "Packet details" was last selected */
+ gboolean packet_data; /* TRUE if "String" search in "Packet data" was last selected */
+ guint32 search_pos; /* Byte position of last byte found in a hex search */
+ guint32 search_len; /* Length of bytes matching the search */
+ gboolean case_type; /* TRUE if case-insensitive text search */
+ GRegex *regex; /* Set if regular expression search */
+ search_charset_t scs_type; /* Character set for text search */
+ search_direction dir; /* Direction in which to do searches */
+ gboolean search_in_progress; /* TRUE if user just clicked OK in the Find dialog or hit <control>N/B */
/* packet data */
- wtap_rec rec; /* Record header */
- Buffer buf; /* Record data */
+ wtap_rec rec; /* Record header */
+ Buffer buf; /* Record data */
/* packet provider */
struct packet_provider_data provider;
/* frames */
- guint32 first_displayed; /* Frame number of first frame displayed */
- guint32 last_displayed; /* Frame number of last frame displayed */
- column_info cinfo; /* Column formatting information */
- frame_data *current_frame; /* Frame data for current frame */
- gint current_row; /* Row number for current frame */
- epan_dissect_t *edt; /* Protocol dissection for currently selected packet */
- field_info *finfo_selected; /* Field info for currently selected field */
- gpointer window; /* Top-level window associated with file */
- gulong computed_elapsed; /* Elapsed time to load the file (in msec). */
-
- guint32 cum_bytes;
+ guint32 first_displayed; /* Frame number of first frame displayed */
+ guint32 last_displayed; /* Frame number of last frame displayed */
+ column_info cinfo; /* Column formatting information */
+ frame_data *current_frame; /* Frame data for current frame */
+ gint current_row; /* Row number for current frame */
+ epan_dissect_t *edt; /* Protocol dissection for currently selected packet */
+ field_info *finfo_selected; /* Field info for currently selected field */
+ gpointer window; /* Top-level window associated with file */
+ gulong computed_elapsed; /* Elapsed time to load the file (in msec). */
+
+ guint32 cum_bytes;
} capture_file;
extern void cap_file_init(capture_file *cf);